==> 0.1.2%2B2.tar.gz: example/lib/menus/bundle_preparation/steps/material_step.dart <==
import 'package:buck_example/menus/bundle_preparation/widgets/step_button.dart';
import 'package:buck/widgets/form/selector.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

List<DropdownMenuItem> alcoholMenuItems = [
  DropdownMenuItem(
    value: '001',
    child: Container(
      padding: EdgeInsets.only(left: 10),
      child: Text('B0220191128'),
    ),
  )
];

class MaterialStep extends StatefulWidget {
  final BoxConstraints viewportConstraints;
  final GestureTapCallback nextTap;

  MaterialStep(this.viewportConstraints, this.nextTap);

  @override
  _MaterialStepState createState() => _MaterialStepState();
}

class _MaterialStepState extends State<MaterialStep> {
  String _alcoholBatch;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: SingleChildScrollView(
        child: new ConstrainedBox(
          constraints: new BoxConstraints(
            minHeight: widget.viewportConstraints.maxHeight - 48.0,
          ),
          child: IntrinsicHeight(
            child: Column(
              children: <Widget>[
                _buildForm(),
                Spacer(flex: 1),
                _buildButtons(),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget _buildForm() {
    return Padding(
      padding: EdgeInsets.symmetric(vertical: 20),
      child: Column(
        children: <Widget>[
          Selector(
            value: _alcoholBatch,
            label: '       酒 精：',
            hint: '请选择酒精批次号',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: '生理盐水：',
            hint: '请选择生理盐水批次号',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: '       双 抗：',
            hint: '请选择双抗批次号',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: '  离 心 瓶：',
            hint: '请选择离心瓶批次号',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: '  培 养 瓶：',
            hint: '请选择培养瓶批次号',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: '  培 养 基：',
            hint: '请选择培养基批次号',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: '      标 本：',
            hint: '请选择标本批次号',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
        ],
      ),
    );
  }

  Widget _buildButtons() {
    return Padding(
      padding: EdgeInsets.only(bottom: 20),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: <Widget>[
          Container(),
          StepButton(
            stepButtonType: StepButtonType.next,
            text: Text('扫描生物安全柜进入初检环节', style: TextStyle(color: Colors.white, fontFamily: 'shouji', fontSize: 18)),

            /// TODO 使用PDA后按钮不可用
            onTap: widget.nextTap,
            disabled: false,
          ),
        ],
      ),
    );
  }
}

==> 0.1.3%2B2.tar.gz: example/lib/menus/bundle_preparation/steps/material_step.dart <==
import 'package:buck_example/menus/bundle_preparation/widgets/step_button.dart';
import 'package:buck/widgets/form/selector.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

List<DropdownMenuItem> alcoholMenuItems = [
  DropdownMenuItem(
    value: '001',
    child: Container(
      padding: EdgeInsets.only(left: 10),
      child: Text('B0220191128'),
    ),
  )
];

class MaterialStep extends StatefulWidget {
  final BoxConstraints viewportConstraints;
  final GestureTapCallback nextTap;

  MaterialStep(this.viewportConstraints, this.nextTap);

  @override
  _MaterialStepState createState() => _MaterialStepState();
}

class _MaterialStepState extends State<MaterialStep> {
  String _alcoholBatch;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: SingleChildScrollView(
        child: new ConstrainedBox(
          constraints: new BoxConstraints(
            minHeight: widget.viewportConstraints.maxHeight - 48.0,
          ),
          child: IntrinsicHeight(
            child: Column(
              children: <Widget>[
                _buildForm(),
                Spacer(flex: 1),
                _buildButtons(),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget _buildForm() {
    return Padding(
      padding: EdgeInsets.symmetric(vertical: 20),
      child: Column(
        children: <Widget>[
          Selector(
            value: _alcoholBatch,
            label: 'Alcohol',
            hint: 'select alcohol batch number',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: 'Normal Saline',
            hint: 'select normal saline batch number',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: 'Double-antibody',
            hint: 'select the double anti batch number',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: 'Centrifuge Bottle',
            hint: 'select batch number of centrifugal bottle',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: 'Culture Bottle',
            hint: 'select batch number of culture bottle',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: 'DMEM',
            hint: 'select the medium batch number',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
          Selector(
            value: _alcoholBatch,
            label: 'Specimen',
            hint: 'select sample batch number',
            store: alcoholMenuItems,
            onChange: (item) => this.setState(() => _alcoholBatch = item),
          ),
        ],
      ),
    );
  }

  Widget _buildButtons() {
    return Padding(
      padding: EdgeInsets.only(bottom: 20),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: <Widget>[
          Container(),
          StepButton(
            stepButtonType: StepButtonType.next,
            text: Text('Next Step', style: TextStyle(color: Colors.white, fontFamily: 'shouji', fontSize: 18)),

            /// TODO 使用PDA后按钮不可用
            onTap: widget.nextTap,
            disabled: false,
          ),
        ],
      ),
    );
  }
}
